/***************************** LICENSE START ***********************************

 Copyright 2012 ECMWF and INPE. This software is distributed under the terms
 of the Apache License version 2.0. In applying this license, ECMWF does not
 waive the privileges and immunities granted to it by virtue of its status as
 an Intergovernmental Organization or submit itself to any jurisdiction.

 ***************************** LICENSE END *************************************/


#pragma once

#include "MvQRequestPanelLine.h"

#include <QString>

class QPlainTextEdit;

class RequestPanel;
class MvIconParameter;

class MvQScrolledTextLine : public MvQRequestPanelLine
{
    Q_OBJECT

public:
    MvQScrolledTextLine(RequestPanel& owner, const MvIconParameter& param);
    ~MvQScrolledTextLine() = default;

    QString currentValue() { return QString(); }
    void addValue(QString) {}

    void refresh(const std::vector<std::string>&);

public slots:
    void slotTextEdited();

protected:
    QPlainTextEdit* textEdit_;
};
